measuretools.multiply_and_scale_contents_of_measures_in_expr
============================================================

.. autofunction:: abjad.tools.measuretools.multiply_and_scale_contents_of_measures_in_expr.multiply_and_scale_contents_of_measures_in_expr
   :noindex:
